@@ -204,7 +204,7 @@ jmvagreemultiClass <- if (requireNamespace('jmvcore', quietly=TRUE)) R6::R6Class
             }
 
         },
-        .plotba = function(image,...){
+        .plotba = function(image, ggtheme,...){
 
             if (is.null(image$state))
                 return(FALSE)
@@ -213,14 +213,15 @@ jmvagreemultiClass <- if (requireNamespace('jmvcore', quietly=TRUE)) R6::R6Class
                           x_name = "Method 1", y_name = "Method 2") +
               labs(y = self$options$ylabel,
                    x = self$options$xlabel) +
+              ggtheme
                 # set transparency
-                theme(
-                    panel.grid.major = element_blank(),
-                    panel.grid.minor = element_blank(),
-                    legend.background = element_rect(fill = "transparent",colour = NA),
-                    panel.background = element_rect(fill = "transparent",colour = NA),
-                    plot.background = element_rect(fill = "transparent",colour = NA)
-                )
+                #theme(
+                #    panel.grid.major = element_blank(),
+                #    panel.grid.minor = element_blank(),
+                #    legend.background = element_rect(fill = "transparent",colour = NA),
+                #    panel.background = element_rect(fill = "transparent",colour = NA),
+                #    plot.background = element_rect(fill = "transparent",colour = NA)
+                #)
 
 
             print(plotpr)
@@ -228,20 +229,21 @@ jmvagreemultiClass <- if (requireNamespace('jmvcore', quietly=TRUE)) R6::R6Class
             return(TRUE)
 
         },
-        .plotcon = function(image,...){
+        .plotcon = function(image,ggtheme,...){
 
             if (is.null(image$state))
                 return(FALSE)
 
             plotpr = plot(image$state, type =2,
                           x_name = "1", y_name = "2")+
+              ggtheme
                 # set transparency
-                theme(
-                    panel.grid.major = element_blank(),
-                    panel.grid.minor = element_blank(),
-                    panel.background = element_rect(fill = "transparent",colour = NA),
-                    plot.background = element_rect(fill = "transparent",colour = NA)
-                )
+                #theme(
+                #    panel.grid.major = element_blank(),
+                #    panel.grid.minor = element_blank(),
+                #    panel.background = element_rect(fill = "transparent",colour = NA),
+                #    plot.background = element_rect(fill = "transparent",colour = NA)
+                #)
 
 
             print(plotpr)
